==> aws-java-sdk-emr-1.11.26-sources.jar: com/amazonaws/services/elasticmapreduce/model/ListBootstrapActionsRequest.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.elasticmapreduce.model;

import java.io.Serializable;
import com.amazonaws.AmazonWebServiceRequest;

/**
 * <p>
 * This input determines which bootstrap actions to retrieve.
 * </p>
 */
public class ListBootstrapActionsRequest extends AmazonWebServiceRequest
        implements Serializable, Cloneable {

    /**
     * <p>
     * The cluster identifier for the bootstrap actions to list .
     * </p>
     */
    private String clusterId;
    /**
     * <p>
     * The pagination token that indicates the next set of results to retrieve .
     * </p>
     */
    private String marker;

    /**
     * <p>
     * The cluster identifier for the bootstrap actions to list .
     * </p>
     * 
     * @param clusterId
     *        The cluster identifier for the bootstrap actions to list .
     */

    public void setClusterId(String clusterId) {
        this.clusterId = clusterId;
    }

    /**
     * <p>
     * The cluster identifier for the bootstrap actions to list .
     * </p>
     * 
     * @return The cluster identifier for the bootstrap actions to list .
     */

    public String getClusterId() {
        return this.clusterId;
    }

    /**
     * <p>
     * The cluster identifier for the bootstrap actions to list .
     * </p>
     * 
     * @param clusterId
     *        The cluster identifier for the bootstrap actions to list .
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public ListBootstrapActionsRequest withClusterId(String clusterId) {
        setClusterId(clusterId);
        return this;
    }

    /**
     * <p>
     * The pagination token that indicates the next set of results to retrieve .
     * </p>
     * 
     * @param marker
     *        The pagination token that indicates the next set of results to
     *        retrieve .
     */

    public void setMarker(String marker) {
        this.marker = marker;
    }

    /**
     * <p>
     * The pagination token that indicates the next set of results to retrieve .
     * </p>
     * 
     * @return The pagination token that indicates the next set of results to
     *         retrieve .
     */

    public String getMarker() {
        return this.marker;
    }

    /**
     * <p>
     * The pagination token that indicates the next set of results to retrieve .
     * </p>
     * 
     * @param marker
     *        The pagination token that indicates the next set of results to
     *        retrieve .
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public ListBootstrapActionsRequest withMarker(String marker) {
        setMarker(marker);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getClusterId() != null)
            sb.append("ClusterId: " + getClusterId() + ",");
        if (getMarker() != null)
            sb.append("Marker: " + getMarker());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof ListBootstrapActionsRequest == false)
            return false;
        ListBootstrapActionsRequest other = (ListBootstrapActionsRequest) obj;
        if (other.getClusterId() == null ^ this.getClusterId() == null)
            return false;
        if (other.getClusterId() != null
                && other.getClusterId().equals(this.getClusterId()) == false)
            return false;
        if (other.getMarker() == null ^ this.getMarker() == null)
            return false;
        if (other.getMarker() != null
                && other.getMarker().equals(this.getMarker()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode
                + ((getClusterId() == null) ? 0 : getClusterId().hashCode());
        hashCode = prime * hashCode
                + ((getMarker() == null) ? 0 : getMarker().hashCode());
        return hashCode;
    }

    @Override
    public ListBootstrapActionsRequest clone() {
        return (ListBootstrapActionsRequest) super.clone();
    }
}

==> aws-java-sdk-emr-1.11.35-sources.jar: com/amazonaws/services/elasticmapreduce/model/ListBootstrapActionsRequest.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.elasticmapreduce.model;

import java.io.Serializable;
import com.amazonaws.AmazonWebServiceRequest;

/**
 * <p>
 * This input determines which bootstrap actions to retrieve.
 * </p>
 */
public class ListBootstrapActionsRequest extends
        com.amazonaws.AmazonWebServiceRequest implements Serializable,
        Cloneable {

    /**
     * <p>
     * The cluster identifier for the bootstrap actions to list .
     * </p>
     */
    private String clusterId;
    /**
     * <p>
     * The pagination token that indicates the next set of results to retrieve .
     * </p>
     */
    private String marker;

    /**
     * <p>
     * The cluster identifier for the bootstrap actions to list .
     * </p>
     * 
     * @param clusterId
     *        The cluster identifier for the bootstrap actions to list .
     */

    public void setClusterId(String clusterId) {
        this.clusterId = clusterId;
    }

    /**
     * <p>
     * The cluster identifier for the bootstrap actions to list .
     * </p>
     * 
     * @return The cluster identifier for the bootstrap actions to list .
     */

    public String getClusterId() {
        return this.clusterId;
    }

    /**
     * <p>
     * The cluster identifier for the bootstrap actions to list .
     * </p>
     * 
     * @param clusterId
     *        The cluster identifier for the bootstrap actions to list .
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public ListBootstrapActionsRequest withClusterId(String clusterId) {
        setClusterId(clusterId);
        return this;
    }

    /**
     * <p>
     * The pagination token that indicates the next set of results to retrieve .
     * </p>
     * 
     * @param marker
     *        The pagination token that indicates the next set of results to
     *        retrieve .
     */

    public void setMarker(String marker) {
        this.marker = marker;
    }

    /**
     * <p>
     * The pagination token that indicates the next set of results to retrieve .
     * </p>
     * 
     * @return The pagination token that indicates the next set of results to
     *         retrieve .
     */

    public String getMarker() {
        return this.marker;
    }

    /**
     * <p>
     * The pagination token that indicates the next set of results to retrieve .
     * </p>
     * 
     * @param marker
     *        The pagination token that indicates the next set of results to
     *        retrieve .
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public ListBootstrapActionsRequest withMarker(String marker) {
        setMarker(marker);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getClusterId() != null)
            sb.append("ClusterId: " + getClusterId() + ",");
        if (getMarker() != null)
            sb.append("Marker: " + getMarker());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof ListBootstrapActionsRequest == false)
            return false;
        ListBootstrapActionsRequest other = (ListBootstrapActionsRequest) obj;
        if (other.getClusterId() == null ^ this.getClusterId() == null)
            return false;
        if (other.getClusterId() != null
                && other.getClusterId().equals(this.getClusterId()) == false)
            return false;
        if (other.getMarker() == null ^ this.getMarker() == null)
            return false;
        if (other.getMarker() != null
                && other.getMarker().equals(this.getMarker()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode
                + ((getClusterId() == null) ? 0 : getClusterId().hashCode());
        hashCode = prime * hashCode
                + ((getMarker() == null) ? 0 : getMarker().hashCode());
        return hashCode;
    }

    @Override
    public ListBootstrapActionsRequest clone() {
        return (ListBootstrapActionsRequest) super.clone();
    }
}
